"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var Showdown = require("showdown");
var ReactMdeSelectionHelper_1 = require("./ReactMdeSelectionHelper");
var HeaderGroup_1 = require("./components/HeaderGroup");
var HeaderItemDropdown_1 = require("./components/HeaderItemDropdown");
var HeaderItem_1 = require("./components/HeaderItem");
var MarkdownHelp_1 = require("./components/MarkdownHelp");
var ReactMde = /** @class */ (function (_super) {
    __extends(ReactMde, _super);
    function ReactMde() {
        var _this = _super.call(this) || this;
        /**
         * Handler for the textArea value change
         * @param {any} e
         * @memberOf ReactMde
         */
        _this.handleValueChange = function (e) {
            var onChange = _this.props.onChange;
            onChange({ text: e.currentTarget.value, selection: null });
        };
        /**
         * Executes a command
         * @param {function} command
         * @memberOf ReactMde
         */
        _this.executeCommand = function (command) {
            var _a = _this.props, text = _a.value.text, onChange = _a.onChange;
            var newValue = command.execute(text, ReactMdeSelectionHelper_1.getSelection(_this.textArea));
            onChange(newValue);
        };
        _this.converter = new Showdown.Converter();
        return _this;
    }
    ReactMde.prototype.componentDidUpdate = function () {
        var selection = this.props.value.selection;
        if (selection) {
            ReactMdeSelectionHelper_1.setSelection(this.textArea, selection.start, selection.end);
        }
    };
    /**
     * Renders react-mde
     * @returns
     * @memberOf ReactMde
     */
    ReactMde.prototype.render = function () {
        var _this = this;
        var _a = this.props, text = _a.value.text, commands = _a.commands, textAreaProps = _a.textAreaProps;
        var html = this.converter.makeHtml(text) || '<p>&nbsp</p>';
        var header = null;
        if (commands) {
            header = (React.createElement("div", { className: "mde-header" }, commands.map(function (cg, i) { return React.createElement(HeaderGroup_1.HeaderGroup, { key: i }, cg.map(function (c, j) {
                if (c.type === 'dropdown') {
                    return (React.createElement(HeaderItemDropdown_1.HeaderItemDropdown, { key: j, icon: c.icon, commands: c.subCommands, onCommand: function (cmd) { return _this.executeCommand(cmd); } }));
                }
                return React.createElement(HeaderItem_1.HeaderItem, { key: j, icon: c.icon, tooltip: c.tooltip, onClick: function () { return _this.executeCommand(c); } });
            })); })));
        }
        return (React.createElement("div", { className: "react-mde" },
            header,
            React.createElement("div", { className: "mde-text" },
                React.createElement("textarea", __assign({ onChange: this.handleValueChange, value: text, ref: function (c) {
                        _this.textArea = c;
                    } }, textAreaProps))),
            React.createElement("div", { className: "mde-preview", dangerouslySetInnerHTML: { __html: html }, ref: function (p) {
                    _this.preview = p;
                } }),
            React.createElement("div", { className: "mde-help" },
                React.createElement(MarkdownHelp_1.MarkdownHelp, null))));
    };
    return ReactMde;
}(React.Component));
exports.ReactMde = ReactMde;
